<?php
// vim:filetype=php expandtab tabstop=2 softtabstop=2 shiftwidth=2 autoindent smartindent
// $Id: tribune.admin.filters.inc,v 1.7 2008/09/11 07:33:22 seeschloss Exp $

function tribune_admin_filters() {
  drupal_set_title(t("Filter settings"));
  $breadcrumb = drupal_get_breadcrumb();
  $breadcrumb[] = l(t("Filter settings"), "admin/settings/tribune/filters");
  drupal_set_breadcrumb($breadcrumb);

  $output  = drupal_get_form("tribune_admin_filters_form", "before");
  $output .= drupal_get_form("tribune_admin_filters_form", "after");
  $output .= drupal_get_form("tribune_admin_filters_reparse_form");
  return $output;
}

function theme_tribune_admin_filters_form($form) {
  $headers = array(
    array('data' => t('Enabled'), 'class' => "checkbox"),
    t('Name'),
    t('Settings'),
    t('Description'),
  );

  $rows = array();
  foreach (element_children($form['filters']) as $filter_name) {
    if (isset($form['filters'][$filter_name]['status'])) {
      $element = &$form['filters'][$filter_name];
      $row = array();
      $row[] = array('data' => drupal_render($element['status']), 'class' => "checkbox");
      $row[] = array('data' => drupal_render($element['name']));
      $row[] = array('data' => drupal_render($element['settings']));
      $row[] = array('data' => drupal_render($element['description']), 'class' => "description");

      $rows[] = $row;
    }
  }

  $output = "";
  if ($rows) {
    $output .= theme("table", $headers, $rows);
  }

  $output .= drupal_render($form);

  $fieldset = array(
    '#type' => "fieldset",
    '#title' => $form['title']['#value'],
    '#description' => $form['description']['#value'],
  );
  $fieldset['contents'] = array(
    '#value' => $output,
  );

  return drupal_render($fieldset);
}

function tribune_admin_filters_form($form, $execution_time = "before") {
  $filters = _tribune_filters_info();
  $all_filters = array();
  $enabled_filters = variable_get('tribune_enabled_filters', array('totoz' => "totoz", "url" => "url"));

  $form = array('#tree' => TRUE);

  foreach ($filters as $filter_name => $attributes) {
    if (($execution_time == "before" and $attributes['before_slip'])
     or ($execution_time == "after"  and $attributes['after_slip'])) {
      $enabled = (isset($enabled_filters[$filter_name]) and $enabled_filters[$filter_name]);

      $all_filters[] = $filter_name;

      $row = array();
      $row['status'] = array(
        '#type' => 'checkbox',
        '#return_value' => TRUE,
        '#default_value' => $enabled,
      );
      $row['name'] = array(
        '#value' => $filter_name,
      );
      $row['settings'] = array(
        '#value' => $enabled ? $filters[$filter_name]['settings'] ? l(t('Settings'), "admin/settings/tribune/filters/settings/". $filter_name) : t('None') : "",
      );
      $row['description'] = array(
        '#value' => $filters[$filter_name]['description'],
      );

      $form['filters'][$filter_name] = $row;
    }
  }
  $form['title'] = array(
    '#type' => "value",
    '#value' => $execution_time == "before" ? t("Filters run before the <em>slip</em>") : t("Filters run after the <em>slip</em>"),
  );
  $form['description'] = array(
    '#type' => "value",
    '#value' => $execution_time == "before" ? t("These filters can only use limited HTML, and can post new messages.") : t("These filters can use full HTML, but can not post new messages."),
  );

  $form['filters-list'] = array(
    '#type' => 'hidden',
    '#value' => serialize($all_filters),
  );

  $form['submit'] = array(
    '#type' => "submit",
    '#value' => t("Save"),
    '#submit' => array("tribune_admin_filters_enable_disable"),
  );

  return $form;
}

function tribune_admin_filters_enable_disable($form, $f) {
  $enabled_filters = variable_get('tribune_enabled_filters', array('totoz' => "totoz", "url" => "url"));

  $all_filters = unserialize($form['#post']['filters-list']);

  if (is_array($form['#post']['filters'])) foreach ($form['#post']['filters'] as $filter_name => $filter) {
    if (isset($filter['status']) and $filter['status']) {
      if (!isset($enabled_filters[$filter_name]) or !$enabled_filters[$filter_name]) {
        $enabled_filters[$filter_name] = $filter_name;
        drupal_set_message(t("The '@filter_name' filter has been enabled.", array('@filter_name' => $filter_name)), "status");
      }
    }
  }

  if (is_array($all_filters)) foreach ($all_filters as $filter_name) {
    if (!isset($form['#post']['filters'][$filter_name]) and isset($enabled_filters[$filter_name])) {
      unset($enabled_filters[$filter_name]);
      drupal_set_message(t("The '@filter_name' filter has been disabled.", array('@filter_name' => $filter_name)), "status");
    }
  }

  variable_set('tribune_enabled_filters', $enabled_filters);
}

function tribune_admin_filters_reparse_form() {
  $form = array();

  $form['tribune_reparse_messages'] = array(
    '#type'      => 'submit',
    '#value'    => t('Parse visible messages again'),
    '#submit'    => array('tribune_parse_last_messages'),
  );

  return $form;
}

function tribune_filter_settings($filter_name) {
  $filters = _tribune_filters_info();

  if (isset($filters[$filter_name]['settings'])) {
    drupal_set_title(t("Filter settings &mdash; ". $filter_name));
    $breadcrumb = drupal_get_breadcrumb();
    $breadcrumb[] = l(t("Filter settings"), "admin/settings/tribune/filters");
    $breadcrumb[] = l($filter_name, "admin/settings/tribune/filters/". $filter_name);
    drupal_set_breadcrumb($breadcrumb);

    $function = $filters[$filter_name]['settings'];

    return drupal_get_form($function);
  }
}

