<?php
// vim:filetype=php expandtab tabstop=2 softtabstop=2 shiftwidth=2 autoindent smartindent
// $Id: tribune.history.inc,v 1.7 2008/11/17 09:50:28 seeschloss Exp $

function tribune_history_page() {
  return drupal_get_form('tribune_history_form_date').
         drupal_get_form('tribune_history_form_user').
         drupal_get_form('tribune_history_form_string');
}

function tribune_history_form_date() {
  $form = array();

  $form['by-date'] = array(
    '#type' => 'fieldset',
    '#title' => t('Messages by date'),
    '#description' => t('See all the messages posted at a specific date.'),
  );
  $form['by-date']['by-date-date'] = array(
    '#type' => 'date',
  );
  $form['by-date']['by-date-submit'] = array(
    '#type' => 'submit',
    '#value' => t('By date'),
    '#submit' => array('tribune_history_by_date_handler'),
  );

  return $form;
}

function tribune_history_form_user() {
  $form['by-user'] = array(
    '#type' => 'fieldset',
    '#title' => t('Messages by user'),
    '#description' => t('See all the messages posted by an user.'),
  );
  $form['by-user']['by-user-user'] = array(
    '#type' => 'textfield',
    '#autocomplete_path' => 'user/autocomplete',
  );
  $form['by-user']['by-user-submit-registered'] = array(
    '#prefix' => '<div class="container-inline">',
    '#type' => 'submit',
    '#value' => t('Registered user'),
    '#submit' => array('tribune_history_by_user_registered_handler'),
  );
  $form['by-user']['by-user-submit-anonymous'] = array(
    '#type' => 'submit',
    '#value' => t('Anonymous user'),
    '#suffix' => '</div>',
    '#submit' => array('tribune_history_by_user_anonymous_handler'),
  );

  return $form;
}

function tribune_history_form_string() {
  $form['by-string'] = array(
    '#type' => 'fieldset',
    '#title' => t('Search messages'),
    '#description' => t('Search messages containing a string.'),
  );
  $form['by-string']['by-string-string'] = array(
    '#type' => 'textfield',
  );
  $form['by-string']['by-string-submit'] = array(
    '#type' => 'submit',
    '#value' => t('Search'),
    '#submit' => array('tribune_history_by_string_handler'),
  );

  return $form;
}

function tribune_history_by_date_handler($form) {
  $date = mktime(0, 0, 0, $form['#post']['by-date-date']['month'], $form['#post']['by-date-date']['day'], $form['#post']['by-date-date']['year']);

  header("Location: ". url("tribune/history/date/". date("Ymd", $date)));
  exit();
}

function tribune_history_by_user_registered_handler($form) {
  header("Location: ". url("tribune/history/user/". $form['#post']['by-user-user']));
  exit();
}

function tribune_history_by_user_anonymous_handler($form) {
  header("Location: ". url("tribune/history/user/anonymous/". $form['#post']['by-user-user']));
  exit();
}

function tribune_history_by_string_handler($form) {
  header("Location: ". url("tribune/history/search/". $form['#post']['by-string-string']));
  exit();
}

function tribune_history_show_posts($tribune_id, $posts) {
  drupal_add_css(drupal_get_path('module', 'tribune') .'/css/tribune.page.css');

  $tribune_id = "tribune-page";
  drupal_add_js(array(
    "tribune" => array(
      "tribunes" => array(
        $tribune_id => array(
          "reload_delay" => 0,
          "block" => FALSE,
          "path" => array(
            "post" => url("tribune/post"),
            "json_post" => url("tribune/post-json"),
            "json_posts" => url("tribune/newposts-json"),
            "filters" => url("tribune/filter"),
          ),
        ),
      ),
    ),
  ), "setting");

  drupal_add_js(drupal_get_path('module', 'tribune') .'/js/tribune.ajax.js');
  drupal_add_js('misc/jquery.form.js');
  foreach(_tribune_get_filters_help() as $filter => $function) {
    $function();
  }
  $date = strtotime($date);

  $contents = "<ul class='tribune-posts tribune-page' id='ul-". $tribune_id ."'>\n";

  $user  = user_load_self(array());
  $login = $user[1]->name;

  if (sizeof($posts) > 0) foreach ($posts as $post) {
    if (!$post['moderated'] || user_access("moderate tribune")) {
      $contents .= theme("tribune_post", $post) ."\n";

      $_tribune_current_post_id = -1;
    }
  }

  $contents .= "</ul>\n";

  return $contents;
}

function tribune_history_select_posts($extra = "", $arguments = array()) {
  $history_size = variable_get("tribune_history_size", 25);

  $posts = array();

  $r = pager_query("SELECT *
                   FROM {tribune} ".
                   $extra,
                   $history_size,
                   0,
                   NULL,
                   $arguments);

  while ($row = db_fetch_array($r)) {
    $posts[$row['post_id']] = tribune_post_from_row($row);
  }

  return $posts;
}

/**
  * Returns all the posts for a day, in a formatted string
  * @param $date Show the posts at this date
  * @return String containing the posts in an HTML unordered list
  */
function tribune_history_by_date($date) {
  $tribune_id = "tribune-history-date-". check_plain($date);

  $posts = tribune_history_select_posts(
                 "WHERE SUBSTRING(post_time FROM 1 FOR 8) = '%s'
               ORDER BY post_id ASC",
                   array($date));

  return tribune_history_show_posts($tribune_id, $posts).theme("pager", array(), $history_size);
}

/**
  * Returns all the posts for an user, in a formatted string
  * @param $user Show the posts from this user
  * @return String containing the posts in an HTML unordered list
  */
function tribune_history_by_user($user) {
  $tribune_id = "tribune-history-user-". check_plain($user);
  $history_size = variable_get("tribune_history_size", 25);

  $posts = tribune_history_select_posts(
                 "WHERE login = '%s'
               ORDER BY post_id DESC",
                   array($user));

  return tribune_history_show_posts($tribune_id, $posts).theme("pager", array(), $history_size);
}

function tribune_history_by_user_anonymous($user) {
  $tribune_id = "tribune-history-user-". check_plain($user);
  $history_size = variable_get("tribune_history_size", 25);

  $user = '%'. str_replace('*', '%', $user) .'%';

  $posts = tribune_history_select_posts(
                 "WHERE info LIKE '%s'
                    AND login = ''
               ORDER BY post_id DESC",
                   array($user));

  return tribune_history_show_posts($tribune_id, $posts).theme("pager", array(), $history_size);
}

function tribune_highlight_string($needle, $haystack) {
  if (preg_match('/<a.*href=.*'. $needle .'.*>/iu', $haystack)) {
    return $haystack;
  }
  else {
    return preg_replace('/'. $needle .'/iu', '<strong>\0</strong>', $haystack);
  }
}

function tribune_history_by_string($string) {
  $tribune_id = "tribune-history-string-". check_plain($string);
  $history_size = variable_get("tribune_history_size", 25);

  $string_sql = '%'. str_replace('*', '%', $string) .'%';

  $posts = tribune_history_select_posts(
                 "WHERE message LIKE '%s'
               ORDER BY post_id DESC",
                   array($string_sql));

  $string_regexp = str_replace('*', '.*', $string);

  foreach ($posts as $id => $post) {
    $posts[$id]['parsed_message'] = tribune_highlight_string($string_regexp, $post['parsed_message']);
  }

  return tribune_history_show_posts($tribune_id, $posts).theme("pager", array(), $history_size);
}

